@@ -11,23 +11,29 @@ class payUnit:
     """
     def __init__(self,data):      
         self.config_data = data
-        if data.keys().count('api_key') == 0:
+        data_keys = list(data.keys())
+        if data_keys.count('api_key') == 0:
             raise Exception('api_key not present')
-        if data.keys().count('user_api') == 0:
+        if data_keys.count('user_api') == 0:
             raise Exception('user_api not present')
-        if data.keys().count('return_url') == 0:
+        if data_keys.count('return_url') == 0:
             raise Exception('return_url not present')
-        if data.keys().count('password_api') == 0:
+        if data_keys.count('password_api') == 0:
             raise Exception('password_api not present')
-        if data.keys().count('mode') == 0:
+        if data_keys.count('mode') == 0:
             raise Exception('sdk mode not present')
+        if data_keys.count('notify_url') == 0:
+            raise Exception('You did not provide a notify url')
         if(data['mode'].lower() != "test" and data['mode'].lower() != "live"):
             raise Exception('Invalid sdk mode')
+        
+                 
+
                  
 
     def makePayment(self,amount): 
         if(int(amount) <= 0):
-            return {"message":"Invalid transaction amount","status":False}
+            raise Exception("Invalid transaction amount")
             
         user_api = self.config_data["user_api"]
         password_api = str(self.config_data["password_api"])
@@ -36,28 +42,27 @@ class payUnit:
         environment = str(self.config_data['mode'])
         base64AuthData = base64.b64encode((auth).encode()).decode()
         return_url = str(self.config_data["return_url"])
-
-        test_url = ''
-        if(environment.lower() == 'test'):
-            test_url = "http://192.168.100.70:5000/api/gateway/initialize"
-        elif(environment.lower() == 'live'):
-            test_url = "http://192.168.100.70:5000/api/gateway/initialize"
-        else:
-            return {"message":" Invalid environment mode ","status": False}
+        notify_url = str(self.config_data["notify_url"])
+        
+        test_url = 'http://192.168.100.70:5000/api/gateway/initialize'
+        # test_url = "http://localhost:5000/notify"
 
         headers = {
             "x-api-key": str(api_key),
             "content-type": "application/json",
-            "Authorization": "Basic "+ str(base64AuthData)
+            "Authorization": "Basic "+ str(base64AuthData),
+            "mode": str(environment.lower()),
         }
 
         test_body = {
+            "notify_url": str(self.config_data['notify_url']),
             "description":"A sample description for a reason for a transaction",
             "transaction_id":  str(uuid.uuid1()),
             "total_amount": str(amount),
-            "return_url": str(self.config_data['return_url'])
+            "return_url": str(self.config_data['return_url']), 
         }
-        # response = requests.post(test_url,auth = HTTPDigestAuth(user_api,password_api),data = json.dumps(test_body),headers = headers)
+        # response = requests.post(test_url,data = json.dumps(test_body),headers = headers)
+        # print(response.content)
         try:   
             response = requests.post(test_url,data = json.dumps(test_body),headers = headers)
             response = response.json()
